# Hyper-parameters
- max_df
- min_df
- ngram_range

### Lenient Unigram Model
- 0.85
- 0
- (1, 1)

### Restrictive Unigram Model
- 0.5
- 0.1
- (1, 1)

### Lenient Bigram Model
- 0.85
- 0
- (1, 2)

### Lenient Trigram Model
- 0.85
- 0
- (1, 3)

### High n-gram Range
- 0.85
- 0 
- (2, 3)